==> dokuwiki_0.0.20080505.orig.tar.gz: dokuwiki-2008-05-05/inc/lang/et/lang.php <==
<?php
/**
 * Estonian language file
 *
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 * @author     Oliver S6ro <seem.iges@mail.ee>
 * @author     Aari Juhanson <aari@vmg.vil.ee>
 * @author     Kaiko Kaur <kaiko@kultuur.edu.ee>
 */
$lang['encoding']   = 'utf-8';
$lang['direction']  = 'ltr';
$lang['doublequoteopening']  = '„';//&bdquo;
$lang['doublequoteclosing']  = '“';//&ldquo;
$lang['singlequoteopening']  = '‚';//&sbquo;
$lang['singlequoteclosing']  = '‘';//&lsquo;

$lang['btn_edit']   = 'Toimeta seda lehte';
$lang['btn_source'] = 'Näita lehepõhja';
$lang['btn_show']   = 'Näita lehte';
$lang['btn_create'] = 'Tekita selle lingi alla leht';
$lang['btn_search'] = 'Otsi';
$lang['btn_save']   = 'Salvesta';
$lang['btn_preview']= 'Eelvaade';
$lang['btn_top']    = 'Tagasi lehe algusesse';
$lang['btn_revs']   = 'Eelmised versioonid';
$lang['btn_recent'] = 'Viimased muudatused';
$lang['btn_upload'] = 'Lae üles';
$lang['btn_cancel'] = 'Katkesta';
$lang['btn_index']  = 'Sisukord';
$lang['btn_secedit']= 'Toimeta';
$lang['btn_login']  = 'Logi sisse';
$lang['btn_logout'] = 'Logi välja';
$lang['btn_admin']  = 'Administreeri';
$lang['btn_update'] = 'Uuenda';
$lang['btn_delete'] = 'Kustuta';
$lang['btn_newer'] = '<< varajasemad';
$lang['btn_older'] = '>> hilisemad';
$lang['btn_back'] = 'Tagasi';
$lang['btn_backtomedia'] = 'Tagasi faili valikusse';
$lang['btn_profile'] = 'Minu info';
$lang['btn_reset'] = 'Taasta';
$lang['btn_resendpwd'] = 'Saada uus parool';
$lang['btn_draft'] = 'Toimeta mustandit';
$lang['btn_recover'] = 'Taata mustand';
$lang['btn_draftdel'] = 'Kustuta mustand';
$lang['newpass'] = 'Uus parool';
$lang['oldpass'] = 'Vana parool';
$lang['passchk'] = 'Korda uut parooli';
$lang['profile'] = 'Kasutaja info';
$lang['minoredit'] = 'Ebaolulised muudatused';
$lang['draftdate'] = 'Mustand automaatselt salvestatud';
$lang['regsuccess2'] = 'Kasutaja sai tehtud.';
$lang['regbadpass'] = 'Uus parool on kirjutatud erinevalt. Proovi uuesti.';
$lang['uploadexist'] = 'Fail on juba olemas. Midagi ei muudetud.';
$lang['deletesucc'] = 'Fail nimega "%s" sai kustutatud.';
$lang['deletefail'] = 'Faili nimega "%s" ei kustutatud (kontrolli õigusi).';
$lang['mediainuse'] = 'Faili nimega "%s" ei kustutatud, sest see on kasutuses.';
$lang['js']['keepopen'] = 'Jäta aken peale valiku sooritamist avatuks';
$lang['js']['hidedetails'] = 'Peida detailid';
$lang['mediausage'] = 'Kasuta järgmist kirjapilti sellele failile viitamaks:';
$lang['mediaview'] = 'Vaata faili algsel kujul.';
$lang['mediaroot'] = 'juur';
$lang['mediaupload'] = 'Lae fail sellesse nimeruumi (kataloogi). Et tekitada veel alam nimeruum kasuta koolonit Wiki nimes.';
$lang['mediaextchange'] = 'Faili laiend .%s-st %s-ks!';
$lang['ref_inuse'] = 'Seda faili ei saa kustutada, sest teda kasutavad järgmised lehed:';
$lang['ref_hidden'] = 'Mõned viidad failile on lehtedel, millele sul ei ole ligipääsu';
$lang['youarehere'] = 'Sa oled siin';
$lang['mail_new_user'] = 'Uus kasutaja:';
$lang['qb_strike'] = 'Läbijoonitud tekst';
$lang['qb_smileys'] = 'Emotikonid';
$lang['qb_chars'] = 'Erisümbolid';
$lang['admin_register'] = 'Lisa kasutaja';


#$lang['reference'] = '';
#$lang['btn_backlink'] = '';
#$lang['profna'] = '';
$lang['btn_subscribe'] = 'Jälgi seda lehte (teated meilile)';
$lang['btn_unsubscribe'] = 'Lõpeta lehe jälgimine';
$lang['profnochange'] = 'Muutused puuduvad.';
$lang['profnoempty'] = 'Tühi nimi ega meiliaadress pole lubatud.';
$lang['profchanged'] = 'Kasutaja info edukalt muudetud';
$lang['pwdforget'] = 'Unustasid parooli? Tee uus';
$lang['resendna'] = 'See wiki ei toeta parooli taassaatmist.';
$lang['resendpwd'] = 'Saada uus parool';
$lang['resendpwdmissing'] = 'Khmm... Sa pead täitma kõik väljad.';
$lang['resendpwdnouser'] = 'Aga sellist kasutajat ei ole.';
$lang['resendpwdbadauth'] = 'See autentimiskood ei ole õige. Kontrolli, et kopeerisid terve lingi.';
$lang['resendpwdconfirm'] = 'Kinnituslink saadeti meilile.';
$lang['resendpwdsuccess'] = 'Uus parool saadeti Sinu meilile.';
$lang['txt_overwrt'] = 'Kirjutan olemasoleva faili üle';
$lang['metaedit'] = 'Muuda lisainfot';
$lang['metasaveerr'] = 'Lisainfo salvestamine läks untsu.';
$lang['metasaveok'] = 'Lisainfo salvestatud';
$lang['img_backto'] = 'Tagasi';
$lang['img_title'] = 'Tiitel';
$lang['img_caption'] = 'Kirjeldus';
$lang['img_date'] = 'Kuupäev';
$lang['img_fname'] = 'Faili nimi';
$lang['img_fsize'] = 'Suurus';
$lang['img_artist'] = 'Autor';
#$lang['img_copyr'] = '';
$lang['img_format'] = 'Formaat';
$lang['img_camera'] = 'Kaamera';
$lang['img_keywords'] = 'Võtmesõnad';

$lang['i_chooselang'] = 'Vali keel';
$lang['i_installer'] = 'DokuWiki paigaldaja';
$lang['i_wikiname'] = 'Wiki nimi';
$lang['i_enableacl'] = 'Kas lubada kasutajate haldus (soovitatav)';
$lang['i_superuser'] = 'Superkasutaja';
$lang['i_problems'] = 'Paigaldaja leidis mõned vead, mis on allpool välja toodud. Enne vigade eemaldamist ei saa jätkata.';
$lang['i_modified'] = 'Õnnetuste vältimiseks läheb see skript käima ainult värskelt paigaldatud ja muutmata Dokuwiki peal.
                       Sa peaksid ilmselt kogu koodi uuesti lahti pakkima. Vaata ka <a href="http://wiki.splitbrain.org/wiki:install">Dokuwiki installeerimis juhendit</a>';
$lang['i_funcna'] = 'PHP funktsiooni <code>%s</code> ei ole olemas.võibolla sinu serveri hooldaja on selle mingil põhjusel keelanud?';
$lang['i_permfail'] = 'Dokuwiki ei saa kirjutada faili <code>%s</code>. Kontrolli serveris failide õigused üle.';
$lang['i_confexists'] = '<code>%s</code> on juba olemas';
$lang['i_writeerr'] = 'Faili <code>%s</code> ei lubata tekitada. Kontrolli kataloogi ja faili õigusi.';
#$lang['i_badhash'] = '';
$lang['i_badval'] = '<code>%s</code> - lubamatu või tühi väärtus';
$lang['i_success'] = 'Seadistamine on õnnelikult lõpule viidud. Sa võid nüüd kustutada faili install.php. Alusta oma <a href="doku.php">uue DokuWiki</a> täitmist.';
$lang['i_failure'] = 'Konfiguratsiooni faili kirjutamisel esines vigu. Võimalik, et pead need käsitsi parandama enne <a href="doku.php">uue DokuWiki</a> täitma asumist.';
$lang['i_policy'] = 'Wiki õiguste algne poliitika';
$lang['i_pol0'] = 'Avatud (lugemine, kirjutamine ja üleslaadimine kõigile lubatud)';
$lang['i_pol1'] = 'Avalikuks lugemiseks (lugeda saavad kõik, kirjutada ja üles laadida vaid registreeritud kasutajad)';
$lang['i_pol2'] = 'Suletud (kõik õigused, kaasaarvatud lugemine on lubatud vaid registreeritud kasutajatele)';

$lang['loggedinas'] = 'Logis sisse kui';
$lang['user']       = 'Kasutaja';
$lang['pass']       = 'Parool';
$lang['remember']   = 'Pea mind meeles';
$lang['fullname']   = 'Täielik nimi';
$lang['email']      = 'E-post';
$lang['register']   = 'Registreeri uus kasutaja';
$lang['badlogin']   = 'Oops, Sinu kasutajanimi või parool oli vale.';

$lang['regmissing'] = 'Kõik väljad tuleb ära täita.';
$lang['reguexists'] = 'Tegelikult on sellise nimega kasutaja juba olemas.';
$lang['regsuccess'] = 'Kasutaja sai tehtud. Parool saadeti Sulle e-posti aadressil.';
$lang['regmailfail']= 'Ilmselt tekkis e-posti teel parooli saatmisel mingi tõrge. Palun suhtle sel teemal 
oma serveri administraatoriga!';
$lang['regbadmail'] = 'Tundub, et Sinu antud e-posti aadress ei toimi - kui Sa arvad, et tegemist on 
ekstitusega, suhtle oma serveri administraatoriga';
$lang['regpwmail']  = 'Sinu DokuWiki parool';
$lang['reghere']    = 'Sul ei olegi veel kasutajakontot? No aga tekita see siis endale!';

$lang['txt_upload']   = 'Vali fail, mida üles laadida';
$lang['txt_filename'] = 'Siseta oma Wikinimi (soovituslik)';
$lang['lockedby']     = 'Praegu on selle lukustanud';
$lang['lockexpire']   = 'Lukustus aegub';
$lang['willexpire']   = 'Teie lukustus selle lehe toimetamisele aegub umbes minuti pärast.\nIgasugu  probleemide vältimiseks kasuta eelvaate nuppu, et lukustusarvesti taas tööle panna.';

$lang['notsavedyet'] = 'Sul on seal salvestamata muudatusi, mis kohe kõige kaduva teed lähevad.\nKas Sa ikka tahad edasi liikuda?'; 
$lang['rssfailed']   = 'Sinu soovitud info ammutamisel tekkis viga: ';
$lang['nothingfound']= 'Oops, aga mitte muhvigi ei leitud.';

$lang['mediaselect'] = 'Hunnik faile';
$lang['fileupload']  = 'Faili üleslaadimine';
$lang['uploadsucc']  = 'Üleslaadimine läks ootuspäraselt hästi';
$lang['uploadfail']  = 'Üleslaadimine läks nässu. Äkki pole Sa selleks lihtsalt piisavalt võimukas tegija?'; 
$lang['uploadwrong'] = 'Ei saa Sa midagi üles laadida. Oops, aga seda tüüpi faili sul lihtsalt ei lubata üles laadida';
$lang['namespaces']  = 'Alajaotus';
$lang['mediafiles']  = 'Failid on Sulle kättesaadavad';

$lang['hits']       = 'Päringu tabamused';
$lang['quickhits']  = 'Päringule vastavad lehed';
$lang['toc']        = 'Sisujuht';
$lang['current']    = 'Hetkel kehtiv';
$lang['yours']      = 'Sinu versioon';
$lang['diff']       = 'Näita erinevusi hetkel kehtiva versiooniga';
$lang['line']       = 'Rida';
$lang['breadcrumb'] = 'Käidud rada';
$lang['lastmod']    = 'Viimati muutnud';
$lang['by']         = 'persoon';
$lang['deleted']    = 'eemaldatud';
$lang['created']    = 'tekitatud';
$lang['restored']   = 'vana versioon taastatud';
$lang['summary']    = 'kokkuvõte muudatustest';

$lang['mail_newpage'] = 'leht lisatud:';
$lang['mail_changed'] = 'leht muudetud';

$lang['nosmblinks'] = 'Windowsis võrguarvutiga ühendamine toimib ainult Internet Exploreris ja 
sisevõrgus.\nAga Sa saad õnneks omale lingi kopeerida ja hiljem kuhugi kleepida.';

$lang['qb_alert']   = 'Sisesta palun tekst, mida Sa tahad kujundada.\nSee lisatakse dokumendi lõppu..'; 
$lang['qb_bold']    = 'Rasvane kiri';
$lang['qb_italic']  = 'Kaldkiri';
$lang['qb_underl']  = 'Alajoonega kiri';
$lang['qb_code']    = 'Koodi tekst';
$lang['qb_h1']      = '1. astme pealkiri';
$lang['qb_h2']      = '2. astme pealkiri';
$lang['qb_h3']      = '3. astme pealkiri';
$lang['qb_h4']      = '4. astme pealkiri';
$lang['qb_h5']      = '5. astme pealkiri';
$lang['qb_link']    = 'Siselink';
$lang['qb_extlink'] = 'Välislink';
$lang['qb_hr']      = 'Horisontaalne vahejoon';
$lang['qb_ol']      = 'Nummerdatud nimikiri';
$lang['qb_ul']      = 'Mummuga nimekiri';
$lang['qb_media']   = 'Lisa pilte ja muid faile';
$lang['qb_sig']     = 'Lisa allkiri!';

$lang['authmodfailed'] = 'Vigane kasutajate autentimise konfiguratsioon. Palun teavita sellest serveri haldajat.';
$lang['authtempfail'] = 'Kasutajate autentimine on ajutiselt rivist väljas. Kui see olukord mõne aja jooksul ei parane, siis teavita sellest serveri haldajat.';

$lang['del_confirm']= 'Kas kustutame selle kirje?';

#$lang['subscribe_success'] = '';
#$lang['subscribe_error'] = '';
#$lang['subscribe_noaddress'] = '';
#$lang['unsubscribe_success'] = '';
#$lang['unsubscribe_error'] = '';

//Setup VIM: ex: et ts=2 enc=utf-8 :

==> dokuwiki_0.0.20090214b.orig.tar.gz: dokuwiki-2009-02-14/inc/lang/et/lang.php <==
<?php
/**
 * Estonian language file
 *
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 * @author     Oliver S6ro <seem.iges@mail.ee>
 * @author     Aari Juhanson <aari@vmg.vil.ee>
 * @author     Kaiko Kaur <kaiko@kultuur.edu.ee>
 */
$lang['encoding']   = 'utf-8';
$lang['direction']  = 'ltr';
$lang['doublequoteopening']  = '„';//&bdquo;
$lang['doublequoteclosing']  = '“';//&ldquo;
$lang['singlequoteopening']  = '‚';//&sbquo;
$lang['singlequoteclosing']  = '‘';//&lsquo;

$lang['btn_edit']   = 'Toimeta seda lehte';
$lang['btn_source'] = 'Näita lehepõhja';
$lang['btn_show']   = 'Näita lehte';
$lang['btn_create'] = 'Tekita selle lingi alla leht';
$lang['btn_search'] = 'Otsi';
$lang['btn_save']   = 'Salvesta';
$lang['btn_preview']= 'Eelvaade';
$lang['btn_top']    = 'Tagasi lehe algusesse';
$lang['btn_revs']   = 'Eelmised versioonid';
$lang['btn_recent'] = 'Viimased muudatused';
$lang['btn_upload'] = 'Lae üles';
$lang['btn_cancel'] = 'Katkesta';
$lang['btn_index']  = 'Sisukord';
$lang['btn_secedit']= 'Toimeta';
$lang['btn_login']  = 'Logi sisse';
$lang['btn_logout'] = 'Logi välja';
$lang['btn_admin']  = 'Administreeri';
$lang['btn_update'] = 'Uuenda';
$lang['btn_delete'] = 'Kustuta';
$lang['btn_newer'] = '<< varajasemad';
$lang['btn_older'] = '>> hilisemad';
$lang['btn_back'] = 'Tagasi';
$lang['btn_backtomedia'] = 'Tagasi faili valikusse';
$lang['btn_profile'] = 'Minu info';
$lang['btn_reset'] = 'Taasta';
$lang['btn_resendpwd'] = 'Saada uus parool';
$lang['btn_draft'] = 'Toimeta mustandit';
$lang['btn_recover'] = 'Taata mustand';
$lang['btn_draftdel'] = 'Kustuta mustand';
$lang['newpass'] = 'Uus parool';
$lang['oldpass'] = 'Vana parool';
$lang['passchk'] = 'Korda uut parooli';
$lang['profile'] = 'Kasutaja info';
$lang['minoredit'] = 'Ebaolulised muudatused';
$lang['draftdate'] = 'Mustand automaatselt salvestatud';
$lang['regsuccess2'] = 'Kasutaja sai tehtud.';
$lang['regbadpass'] = 'Uus parool on kirjutatud erinevalt. Proovi uuesti.';
$lang['uploadexist'] = 'Fail on juba olemas. Midagi ei muudetud.';
$lang['deletesucc'] = 'Fail nimega "%s" sai kustutatud.';
$lang['deletefail'] = 'Faili nimega "%s" ei kustutatud (kontrolli õigusi).';
$lang['mediainuse'] = 'Faili nimega "%s" ei kustutatud, sest see on kasutuses.';
$lang['js']['keepopen'] = 'Jäta aken peale valiku sooritamist avatuks';
$lang['js']['hidedetails'] = 'Peida detailid';
$lang['mediausage'] = 'Kasuta järgmist kirjapilti sellele failile viitamaks:';
$lang['mediaview'] = 'Vaata faili algsel kujul.';
$lang['mediaroot'] = 'juur';
$lang['mediaupload'] = 'Lae fail sellesse nimeruumi (kataloogi). Et tekitada veel alam nimeruum kasuta koolonit Wiki nimes.';
$lang['mediaextchange'] = 'Faili laiend .%s-st %s-ks!';
$lang['ref_inuse'] = 'Seda faili ei saa kustutada, sest teda kasutavad järgmised lehed:';
$lang['ref_hidden'] = 'Mõned viidad failile on lehtedel, millele sul ei ole ligipääsu';
$lang['youarehere'] = 'Sa oled siin';
$lang['mail_new_user'] = 'Uus kasutaja:';
$lang['qb_strike'] = 'Läbijoonitud tekst';
$lang['qb_smileys'] = 'Emotikonid';
$lang['qb_chars'] = 'Erisümbolid';
$lang['admin_register'] = 'Lisa kasutaja';


#$lang['reference'] = '';
#$lang['btn_backlink'] = '';
#$lang['profna'] = '';
$lang['btn_subscribe'] = 'Jälgi seda lehte (teated meilile)';
$lang['btn_unsubscribe'] = 'Lõpeta lehe jälgimine';
$lang['profnochange'] = 'Muutused puuduvad.';
$lang['profnoempty'] = 'Tühi nimi ega meiliaadress pole lubatud.';
$lang['profchanged'] = 'Kasutaja info edukalt muudetud';
$lang['pwdforget'] = 'Unustasid parooli? Tee uus';
$lang['resendna'] = 'See wiki ei toeta parooli taassaatmist.';
$lang['resendpwd'] = 'Saada uus parool';
$lang['resendpwdmissing'] = 'Khmm... Sa pead täitma kõik väljad.';
$lang['resendpwdnouser'] = 'Aga sellist kasutajat ei ole.';
$lang['resendpwdbadauth'] = 'See autentimiskood ei ole õige. Kontrolli, et kopeerisid terve lingi.';
$lang['resendpwdconfirm'] = 'Kinnituslink saadeti meilile.';
$lang['resendpwdsuccess'] = 'Uus parool saadeti Sinu meilile.';
$lang['txt_overwrt'] = 'Kirjutan olemasoleva faili üle';
$lang['metaedit'] = 'Muuda lisainfot';
$lang['metasaveerr'] = 'Lisainfo salvestamine läks untsu.';
$lang['metasaveok'] = 'Lisainfo salvestatud';
$lang['img_backto'] = 'Tagasi';
$lang['img_title'] = 'Tiitel';
$lang['img_caption'] = 'Kirjeldus';
$lang['img_date'] = 'Kuupäev';
$lang['img_fname'] = 'Faili nimi';
$lang['img_fsize'] = 'Suurus';
$lang['img_artist'] = 'Autor';
#$lang['img_copyr'] = '';
$lang['img_format'] = 'Formaat';
$lang['img_camera'] = 'Kaamera';
$lang['img_keywords'] = 'Võtmesõnad';

$lang['i_chooselang'] = 'Vali keel';
$lang['i_installer'] = 'DokuWiki paigaldaja';
$lang['i_wikiname'] = 'Wiki nimi';
$lang['i_enableacl'] = 'Kas lubada kasutajate haldus (soovitatav)';
$lang['i_superuser'] = 'Superkasutaja';
$lang['i_problems'] = 'Paigaldaja leidis mõned vead, mis on allpool välja toodud. Enne vigade eemaldamist ei saa jätkata.';
$lang['i_modified'] = 'Õnnetuste vältimiseks läheb see skript käima ainult värskelt paigaldatud ja muutmata Dokuwiki peal.
                       Sa peaksid ilmselt kogu koodi uuesti lahti pakkima. Vaata ka <a href="http://dokuwiki.org/install">Dokuwiki installeerimis juhendit</a>';
$lang['i_funcna'] = 'PHP funktsiooni <code>%s</code> ei ole olemas.võibolla sinu serveri hooldaja on selle mingil põhjusel keelanud?';
$lang['i_permfail'] = 'Dokuwiki ei saa kirjutada faili <code>%s</code>. Kontrolli serveris failide õigused üle.';
$lang['i_confexists'] = '<code>%s</code> on juba olemas';
$lang['i_writeerr'] = 'Faili <code>%s</code> ei lubata tekitada. Kontrolli kataloogi ja faili õigusi.';
#$lang['i_badhash'] = '';
$lang['i_badval'] = '<code>%s</code> - lubamatu või tühi väärtus';
$lang['i_success'] = 'Seadistamine on õnnelikult lõpule viidud. Sa võid nüüd kustutada faili install.php. Alusta oma <a href="doku.php">uue DokuWiki</a> täitmist.';
$lang['i_failure'] = 'Konfiguratsiooni faili kirjutamisel esines vigu. Võimalik, et pead need käsitsi parandama enne <a href="doku.php">uue DokuWiki</a> täitma asumist.';
$lang['i_policy'] = 'Wiki õiguste algne poliitika';
$lang['i_pol0'] = 'Avatud (lugemine, kirjutamine ja üleslaadimine kõigile lubatud)';
$lang['i_pol1'] = 'Avalikuks lugemiseks (lugeda saavad kõik, kirjutada ja üles laadida vaid registreeritud kasutajad)';
$lang['i_pol2'] = 'Suletud (kõik õigused, kaasaarvatud lugemine on lubatud vaid registreeritud kasutajatele)';

$lang['loggedinas'] = 'Logis sisse kui';
$lang['user']       = 'Kasutaja';
$lang['pass']       = 'Parool';
$lang['remember']   = 'Pea mind meeles';
$lang['fullname']   = 'Täielik nimi';
$lang['email']      = 'E-post';
$lang['register']   = 'Registreeri uus kasutaja';
$lang['badlogin']   = 'Oops, Sinu kasutajanimi või parool oli vale.';

$lang['regmissing'] = 'Kõik väljad tuleb ära täita.';
$lang['reguexists'] = 'Tegelikult on sellise nimega kasutaja juba olemas.';
$lang['regsuccess'] = 'Kasutaja sai tehtud. Parool saadeti Sulle e-posti aadressil.';
$lang['regmailfail']= 'Ilmselt tekkis e-posti teel parooli saatmisel mingi tõrge. Palun suhtle sel teemal 
oma serveri administraatoriga!';
$lang['regbadmail'] = 'Tundub, et Sinu antud e-posti aadress ei toimi - kui Sa arvad, et tegemist on 
ekstitusega, suhtle oma serveri administraatoriga';
$lang['regpwmail']  = 'Sinu DokuWiki parool';
$lang['reghere']    = 'Sul ei olegi veel kasutajakontot? No aga tekita see siis endale!';

$lang['txt_upload']   = 'Vali fail, mida üles laadida';
$lang['txt_filename'] = 'Siseta oma Wikinimi (soovituslik)';
$lang['lockedby']     = 'Praegu on selle lukustanud';
$lang['lockexpire']   = 'Lukustus aegub';
$lang['willexpire']   = 'Teie lukustus selle lehe toimetamisele aegub umbes minuti pärast.\nIgasugu  probleemide vältimiseks kasuta eelvaate nuppu, et lukustusarvesti taas tööle panna.';

$lang['notsavedyet'] = 'Sul on seal salvestamata muudatusi, mis kohe kõige kaduva teed lähevad.\nKas Sa ikka tahad edasi liikuda?'; 
$lang['rssfailed']   = 'Sinu soovitud info ammutamisel tekkis viga: ';
$lang['nothingfound']= 'Oops, aga mitte muhvigi ei leitud.';

$lang['mediaselect'] = 'Hunnik faile';
$lang['fileupload']  = 'Faili üleslaadimine';
$lang['uploadsucc']  = 'Üleslaadimine läks ootuspäraselt hästi';
$lang['uploadfail']  = 'Üleslaadimine läks nässu. Äkki pole Sa selleks lihtsalt piisavalt võimukas tegija?'; 
$lang['uploadwrong'] = 'Ei saa Sa midagi üles laadida. Oops, aga seda tüüpi faili sul lihtsalt ei lubata üles laadida';
$lang['namespaces']  = 'Alajaotus';
$lang['mediafiles']  = 'Failid on Sulle kättesaadavad';

$lang['hits']       = 'Päringu tabamused';
$lang['quickhits']  = 'Päringule vastavad lehed';
$lang['toc']        = 'Sisujuht';
$lang['current']    = 'Hetkel kehtiv';
$lang['yours']      = 'Sinu versioon';
$lang['diff']       = 'Näita erinevusi hetkel kehtiva versiooniga';
$lang['line']       = 'Rida';
$lang['breadcrumb'] = 'Käidud rada';
$lang['lastmod']    = 'Viimati muutnud';
$lang['by']         = 'persoon';
$lang['deleted']    = 'eemaldatud';
$lang['created']    = 'tekitatud';
$lang['restored']   = 'vana versioon taastatud';
$lang['summary']    = 'kokkuvõte muudatustest';

$lang['mail_newpage'] = 'leht lisatud:';
$lang['mail_changed'] = 'leht muudetud';

$lang['nosmblinks'] = 'Windowsis võrguarvutiga ühendamine toimib ainult Internet Exploreris ja 
sisevõrgus.\nAga Sa saad õnneks omale lingi kopeerida ja hiljem kuhugi kleepida.';

$lang['qb_alert']   = 'Sisesta palun tekst, mida Sa tahad kujundada.\nSee lisatakse dokumendi lõppu..'; 
$lang['qb_bold']    = 'Rasvane kiri';
$lang['qb_italic']  = 'Kaldkiri';
$lang['qb_underl']  = 'Alajoonega kiri';
$lang['qb_code']    = 'Koodi tekst';
$lang['qb_h1']      = '1. astme pealkiri';
$lang['qb_h2']      = '2. astme pealkiri';
$lang['qb_h3']      = '3. astme pealkiri';
$lang['qb_h4']      = '4. astme pealkiri';
$lang['qb_h5']      = '5. astme pealkiri';
$lang['qb_link']    = 'Siselink';
$lang['qb_extlink'] = 'Välislink';
$lang['qb_hr']      = 'Horisontaalne vahejoon';
$lang['qb_ol']      = 'Nummerdatud nimikiri';
$lang['qb_ul']      = 'Mummuga nimekiri';
$lang['qb_media']   = 'Lisa pilte ja muid faile';
$lang['qb_sig']     = 'Lisa allkiri!';

$lang['authmodfailed'] = 'Vigane kasutajate autentimise konfiguratsioon. Palun teavita sellest serveri haldajat.';
$lang['authtempfail'] = 'Kasutajate autentimine on ajutiselt rivist väljas. Kui see olukord mõne aja jooksul ei parane, siis teavita sellest serveri haldajat.';

$lang['del_confirm']= 'Kas kustutame selle kirje?';

#$lang['subscribe_success'] = '';
#$lang['subscribe_error'] = '';
#$lang['subscribe_noaddress'] = '';
#$lang['unsubscribe_success'] = '';
#$lang['unsubscribe_error'] = '';

//Setup VIM: ex: et ts=2 enc=utf-8 :
